@@ -14,12 +14,23 @@ class LogbookPlugin(Plugin):  # pragma: no cover
     def help(self):
         return 'logbook compatability'
 
-    def begin(self):
+    def _send_logbook_records_to_standard_logging(self):
         try:
             from logbook.compat import LoggingHandler
-            from logbook.concurrency import enable_gevent
         except ImportError:
             pass
         else:
             LoggingHandler().push_application()
+
+    def _enable_logbook_gevent(self):
+        try:
+            from logbook.concurrency import enable_gevent
+        except ImportError:
+            pass
+        else:
             enable_gevent()
+
+    def begin(self):
+        self._enable_logbook_gevent()
+        self._send_logbook_records_to_standard_logging()
+
